@@ -66,7 +66,7 @@ def _get_paths_object(document):
 
     for operation_id, link, tags in links:
         if link.url not in paths:
-            paths[link.url] = {}
+            paths[link.url] = OrderedDict()
 
         method = get_method(link)
         operation = _get_operation(operation_id, link, tags)
@@ -77,13 +77,19 @@ def _get_paths_object(document):
 
 def _get_operation(operation_id, link, tags):
     encoding = get_encoding(link)
+    description = link.description.strip()
+    summary = description.splitlines()[0] if description else None
 
     operation = {
         'operationId': operation_id,
-        'description': link.description,
         'responses': _get_responses(link),
         'parameters': _get_parameters(link, encoding)
     }
+
+    if description:
+        operation['description'] = description
+    if summary:
+        operation['summary'] = summary
     if encoding:
         operation['consumes'] = [encoding]
     if tags:
@@ -109,15 +115,24 @@ def _get_parameters(link, encoding):
                     'required': field.required,
                     'in': 'formData',
                     'description': field.description,
-                    'type': 'string'
+                    'type': field.type or 'string',
                 }
+                if field.type == 'array':
+                    parameter['items'] = {'type': 'string'}
                 parameters.append(parameter)
             else:
                 # Expand coreapi fields with location='form' into a single swagger
                 # parameter, with a schema containing multiple properties.
+                use_type = field.type or 'string'
+                if use_type == 'file':
+                    use_type = 'string'
+
                 schema_property = {
-                    'description': field.description
+                    'description': field.description,
+                    'type': use_type,
                 }
+                if field.type == 'array':
+                    schema_property['items'] = {'type': 'string'}
                 properties[field.name] = schema_property
                 if field.required:
                     required.append(field.name)
@@ -141,20 +156,24 @@ def _get_parameters(link, encoding):
                 'required': field.required,
                 'in': location,
                 'description': field.description,
-                'type': 'string'
+                'type': field.type or 'string',
             }
+            if field.type == 'array':
+                parameter['items'] = {'type': 'string'}
             parameters.append(parameter)
 
     if properties:
-        parameters.append({
+        parameter = {
             'name': 'data',
             'in': 'body',
             'schema': {
                 'type': 'object',
-                'properties': properties,
-                'required': required
+                'properties': properties
             }
-        })
+        }
+        if required:
+            parameter['schema']['required'] = required
+        parameters.append(parameter)
 
     return parameters
 
