@@ -1,3 +1,12 @@
+/*
+@header({
+  searchable: 2,
+  filterable: 0,
+  quickSearch: 0,
+  title: 'GAZE'
+})
+*/
+
 globalThis.window = globalThis.global = globalThis;
 
 class Go {
